DefaultResolver

Struct DefaultResolver 

pub struct DefaultResolver { /* private fields */ }
Default resolver implementation.

Uses std::net ToSocketAddrs to do the lookup. Can optionally spawn a thread to abort lookup if the relevant timeout is set.

Implementations

Source

impl DefaultResolver

pub fn host_and_port(scheme: &Scheme, authority: &Authority) -> Option<String>

Helper to combine scheme host and port to a single string.

This knows about the default ports for http, https and socks proxies which can then be omitted from the Authority.